@@ -1,6 +1,6 @@
 /*
- * Copyright(c) 2014 Tim Ruehsen
- * Copyright(c) 2015-2019 Free Software Foundation, Inc.
+ * Copyright (c) 2014 Tim Ruehsen
+ * Copyright (c) 2015-2022 Free Software Foundation, Inc.
  *
  * This file is part of libwget.
  *
@@ -126,7 +126,7 @@ static void free_ocsp(ocsp_entry *ocsp)
 	}
 }
 
-static ocsp_entry *new_ocsp(const char *fingerprint, time_t maxage, bool valid)
+static ocsp_entry *new_ocsp(const char *fingerprint, int64_t maxage, bool valid)
 {
 	if (fingerprint) {
 		if (!(fingerprint = wget_strdup(fingerprint)))
@@ -320,7 +320,7 @@ static void ocsp_db_add_fingerprint_entry(wget_ocsp_db *ocsp_db, ocsp_entry *ocs
  * This function is thread-safe and can be called from multiple threads concurrently.
  * Any implementation for this function must be thread-safe as well.
  */
-void wget_ocsp_db_add_fingerprint(wget_ocsp_db *ocsp_db, const char *fingerprint, time_t maxage, bool valid)
+void wget_ocsp_db_add_fingerprint(wget_ocsp_db *ocsp_db, const char *fingerprint, int64_t maxage, bool valid)
 {
 	if (plugin_vtable) {
 		plugin_vtable->add_fingerprint(ocsp_db, fingerprint, maxage, valid);
@@ -389,7 +389,7 @@ static void ocsp_db_add_host_entry(wget_ocsp_db *ocsp_db, ocsp_entry *ocsp)
  * This function is thread-safe and can be called from multiple threads concurrently.
  * Any implementation for this function must be thread-safe as well.
  */
-void wget_ocsp_db_add_host(wget_ocsp_db *ocsp_db, const char *host, time_t maxage)
+void wget_ocsp_db_add_host(wget_ocsp_db *ocsp_db, const char *host, int64_t maxage)
 {
 	if (plugin_vtable) {
 		plugin_vtable->add_host(ocsp_db, host, maxage);
@@ -527,15 +527,21 @@ int wget_ocsp_db_load(wget_ocsp_db *ocsp_db)
 }
 
 WGET_GCC_NONNULL_ALL
-static int ocsp_save_fingerprint(FILE *fp, const ocsp_entry *ocsp)
+static int ocsp_save_fingerprint(void *_fp, const void *_ocsp, WGET_GCC_UNUSED void *v)
 {
+	FILE *fp = _fp;
+	const ocsp_entry *ocsp = _ocsp;
+
 	wget_fprintf(fp, "%s %lld %lld %d\n", ocsp->key, (long long)ocsp->maxage, (long long)ocsp->mtime, ocsp->valid);
 	return 0;
 }
 
 WGET_GCC_NONNULL_ALL
-static int ocsp_save_host(FILE *fp, const ocsp_entry *ocsp)
+static int ocsp_save_host(void *_fp, const void *_ocsp, WGET_GCC_UNUSED void *v)
 {
+	FILE *fp = _fp;
+	const ocsp_entry *ocsp = _ocsp;
+
 	wget_fprintf(fp, "%s %lld %lld\n", ocsp->key, (long long)ocsp->maxage, (long long)ocsp->mtime);
 	return 0;
 }
@@ -546,9 +552,9 @@ static int ocsp_db_save_hosts(void *ocsp_db, FILE *fp)
 
 	if ((wget_hashmap_size(map)) > 0) {
 		fputs("#OCSP 1.0 host file\n", fp);
-		fputs("#Generated by Wget " PACKAGE_VERSION ". Edit at your own risk.\n", fp);
+		fputs("#Generated by libwget " PACKAGE_VERSION ". Edit at your own risk.\n", fp);
 		fputs("<hostname> <time_t maxage> <time_t mtime>\n\n", fp);
-		wget_hashmap_browse(map, (wget_hashmap_browse_fn *) ocsp_save_host, fp);
+		wget_hashmap_browse(map, ocsp_save_host, fp);
 
 		if (ferror(fp))
 			return -1;
@@ -566,7 +572,7 @@ static int ocsp_db_save_fingerprints(void *ocsp_db, FILE *fp)
 		fputs("#OCSP 1.0 fingerprint file\n", fp);
 		fputs("#Generated by Wget " PACKAGE_VERSION ". Edit at your own risk.\n", fp);
 		fputs("<sha256 fingerprint of cert> <time_t maxage> <time_t mtime> <valid>\n\n", fp);
-		wget_hashmap_browse(map, (wget_hashmap_browse_fn *) ocsp_save_fingerprint, fp);
+		wget_hashmap_browse(map, ocsp_save_fingerprint, fp);
 
 		if (ferror(fp))
 			return -1;
