@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019-2021 Free Software Foundation, Inc.
+ * Copyright (c) 2019-2022 Free Software Foundation, Inc.
  *
  * This file is part of libwget.
  *
@@ -883,8 +883,8 @@ int wget_ssl_open(wget_tcp *tcp)
 			xfree(alpn);
 	}
 
-	struct session_context *ctx = wget_calloc(1, sizeof(struct session_context));
-	ctx->hostname = wget_strdup(hostname);
+	// struct session_context *ctx = wget_calloc(1, sizeof(struct session_context));
+	// ctx->hostname = wget_strdup(hostname);
 
 	tcp->ssl_session = session;
 //	gnutls_session_set_ptr(session, ctx);
@@ -934,7 +934,8 @@ int wget_ssl_open(wget_tcp *tcp)
 			debug_printf("WolfSSL: Failed to connect ALPN\n");
 		else {
 			debug_printf("WolfSSL: Server accepted ALPN protocol '%.*s'\n", (int) protocol_length, protocol);
-			stats.alpn_protocol = wget_strmemdup(protocol, protocol_length);
+			if (tls_stats_callback)
+				stats.alpn_protocol = wget_strmemdup(protocol, protocol_length);
 
 			if (protocol_length == 2 && !memcmp(protocol, "h2", 2)) {
 				tcp->protocol = WGET_PROTOCOL_HTTP_2_0;
@@ -1004,13 +1005,13 @@ int wget_ssl_open(wget_tcp *tcp)
 		xfree(stats.alpn_protocol);
 	}
 
-	tcp->hpkp = ctx->stats_hpkp;
+	// tcp->hpkp = ctx->stats_hpkp;
 
 	if (ret != WGET_E_SUCCESS) {
 		if (ret == WGET_E_TIMEOUT)
 			debug_printf("Handshake timed out\n");
-		xfree(ctx->hostname);
-		xfree(ctx);
+		// xfree(ctx->hostname);
+		// xfree(ctx);
 		wolfSSL_free(session);
 		tcp->ssl_session = NULL;
 	}
